/**
 * Module to interact with the location on map module-specific part of the SDK.
 *
 * @beta
 * @module
 */
import { Location } from './geoLocation';
/**
 * Allows user to choose location on map
 *
 * @returns Promise that will resolve with {@link geoLocation.Location} object chosen by the user or reject with an error. Function can also throw a NOT_SUPPORTED_ON_PLATFORM error
 *
 * @beta
 */
export declare function chooseLocation(): Promise<Location>;
/**
 * Shows the location on map corresponding to the given coordinates
 *
 * @param location - Location to be shown on the map
 * @returns Promise that resolves when the location dialog has been closed or reject with an error. Function can also throw a NOT_SUPPORTED_ON_PLATFORM error
 *
 * @beta
 */
export declare function showLocation(location: Location): Promise<void>;
/**
 * Checks if geoLocation.map capability is supported by the host
 * @returns boolean to represent whether geoLocation.map is supported
 *
 * @throws Error if {@linkcode app.initialize} has not successfully completed
 *
 * @beta
 */
export declare function isSupported(): boolean;
